<template>
    <div class="system-user-container">
        <el-card shadow="hover">
            <div class="system-user-search mb15">
                <el-input size="default" v-model.trim="listQuery.searchParams.positionName" placeholder="请输入职务名称" style="max-width: 180px;margin-left: 10px;margin-right: 10px"> </el-input>
                <el-button size="default" type="primary" class="ml10" @click="initDutyTableData">
                    <el-icon>
                        <ele-Search />
                    </el-icon>
                    查询
                </el-button>
                <el-button size="default" type="success" class="ml10" @click="onOpenUserDialog('新增', '')">
                    <el-icon>
                        <ele-FolderAdd />
                    </el-icon>
                    新增职务
                </el-button>
            </div>
            <el-table :data="data" style="width: 100%">
                <el-table-column type="index" label="序号" width="60" align="center"/>
                <el-table-column prop="positionName" label="职务名称" show-overflow-tooltip align="center"></el-table-column>
                <el-table-column prop="createBy" label="创建人" show-overflow-tooltip align="center"></el-table-column>
                <el-table-column prop="gmtCreate" label="创建时间" show-overflow-tooltip align="center"></el-table-column>
                <el-table-column label="操作" width="100" align="center">
                    <template #default="scope">
                        <el-button :disabled="scope.row.userName === 'admin'" size="small" text type="primary" @click="onOpenUserDialog('修改', scope.row)">修改</el-button>
                        <el-button style="color: red" :disabled="scope.row.userName === 'admin'" size="small" text type="primary" @click="onRowDel(scope.row)">删除</el-button>
                    </template>
                </el-table-column>
            </el-table>
            <br />
            <el-pagination @size-change="onHandleSizeChange" @current-change="onHandleCurrentChange" class="page-position" :pager-count="5" :page-sizes="[10, 20, 30]" v-model:current-page="listQuery.pageIndex" background v-model:page-size="listQuery.pageSize" layout="total, sizes, prev, pager, next, jumper" :total="total"> </el-pagination>
            <br />
            <br />
        </el-card>
        <duty-dialog ref="dutyRef" @getDutyList="initDutyTableData" />
    </div>
</template>

<script lang="ts">
import { toRefs, reactive, onMounted, ref, defineComponent } from 'vue';
import { ElMessageBox, ElMessage } from 'element-plus';
import dutyDialog from './component/dutyDialog.vue';
import { dutyApi } from '/@/api/systemManage/duty';
import { departmentApi } from '/@/api/systemManage/department';
import { useRoleApi } from '/@/api/systemManage/role';

// 定义接口来定义对象的类型
interface TableDataRow {
    name: string;
    info: string;
    createTime: string;
}
interface TableDataState {
    data: Array<TableDataRow>;
    total: number;
    loading: boolean;
    listQuery: {
        searchParams: {
          positionName: string | null
          positionCode: string | null
        };
        pageIndex: number;
        pageSize: number;
    }
}

export default defineComponent({
    name: 'systemDuty',
    components: { dutyDialog },
    setup() {
        const dutyRef = ref();
        const state = reactive<TableDataState>({
            data: [],
            total: 0,
            loading: false,
            listQuery: {
                searchParams: {
                  positionName: '',
                  positionCode: ''
                },
                pageIndex: 1,
                pageSize: 10
            }
        });
        // 初始化表格数据
        const initDutyTableData = async () => {
            let res = await dutyApi().getDutyList(state.listQuery);
            if (res.data.code === '200') {
                console.log(res.data.data,'res.data.data')
                state.data = JSON.parse(JSON.stringify(res.data.data));
                state.total = res.data.total;
            } else {
                ElMessage({
                    type: 'warning',
                    message: res.data.msg
                });
            }
        };


        // 打开新增修改职务弹窗
        const onOpenUserDialog = (type: string, value: any) => {
            dutyRef.value.openDialog(type, value);
        };

        // 删除用户
        const onRowDel = (row: TableDataRow) => {
            ElMessageBox.confirm(`此操作将永久删除该职务：“${row.positionName}”，是否继续?`, '提示', {
                confirmButtonText: '确认',
                cancelButtonText: '取消',
                type: 'warning'
            })
                .then(async () => {
                    let res = await dutyApi().delDuty({ positionId: row.positionId });
                    if (res.data.code === '200') {
                        ElMessage({
                            type: 'success',
                            duration: 2000,
                            message: '删除成功'
                        });
                        await initDutyTableData();
                    } else {
                        ElMessage({
                            type: 'warning',
                            message: res.data.msg
                        });
                    }
                })
                .catch(() => {});
        };
        // 分页改变
        const onHandleSizeChange = (val: number) => {
            state.listQuery.pageSize = val;
            initDutyTableData();
        };
        // 分页改变
        const onHandleCurrentChange = (val: number) => {
            state.listQuery.pageIndex = val;
            initDutyTableData();
        };
        // 页面加载时
        onMounted(() => {
            let a = { name: 1, c: { name: 1 } };
            let b = Object.assign({}, a);
            b.c.name = 2;
            initDutyTableData();
        });
        return {
            dutyRef,
            onOpenUserDialog,
            onRowDel,
            onHandleSizeChange,
            initDutyTableData,
            onHandleCurrentChange,
            ...toRefs(state)
        };
    }
});
</script>
<style  scoped>
:deep(.el-textarea.is-disabled .el-textarea__inner) {
    background-color: var(--el-card-bg-color);
    color: var(--el-input-text-color, var(--el-text-color-regular));
}
:deep(.el-input.is-disabled .el-input__inner) {
    color: var(--el-input-text-color, var(--el-text-color-regular));
}
:deep(.el-input.is-disabled .el-input__wrapper) {
    background-color: var(--el-card-bg-color);
}
</style>
